==> haskell-implicit-hie-0.1.2.7-38-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-implicit-hie.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 implicit-hie
version:              0.1.2.7
visibility:           public
id:                   implicit-hie-0.1.2.7-FcwB4wUHS2aCCedMbJBJDn
key:                  implicit-hie-0.1.2.7-FcwB4wUHS2aCCedMbJBJDn
license:              BSD-3-Clause
copyright:            2020
maintainer:           avi.the.coder@gmail.com
author:               Avi Dessauer
homepage:             https://github.com/Avi-D-coder/implicit-hie#readme
synopsis:             Auto generate hie-bios cradles & hie.yaml
description:
    Auto generate a stack or cabal multi component hie.yaml file

category:             Development, Tools, Hie, HLS
abi:                  b7d0cbfac727e42da73390fd5317b743
exposed:              True
exposed-modules:      Hie.Cabal.Parser Hie.Locate Hie.Yaml
hidden-modules:       Paths_implicit_hie
import-dirs:          /usr/lib/ghc-9.0.2/site-local/implicit-hie-0.1.2.7
library-dirs:         /usr/lib/ghc-9.0.2/site-local/implicit-hie-0.1.2.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-implicit-hie
hs-libraries:         HSimplicit-hie-0.1.2.7-FcwB4wUHS2aCCedMbJBJDn
depends:
    attoparsec-0.14.4-R00hSHCjmo7OsW0dxMCO2 base-4.15.1.0
    directory-1.3.6.2 filepath-1.4.2.1
    filepattern-0.1.3-JWWkSpPepRsKTg6bRzQIiZ text-1.2.5.0
    transformers-0.5.6.2 yaml-0.11.8.0-IDyhufKFc0q55Rf4qCveui

haddock-interfaces:
    /usr/share/doc/haskell-implicit-hie/html/implicit-hie.haddock

haddock-html:         /usr/share/doc/haskell-implicit-hie/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-implicit-hie-0.1.2.7-55-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-implicit-hie.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 implicit-hie
version:              0.1.2.7
visibility:           public
id:                   implicit-hie-0.1.2.7-5uI3FDBz7fb6YiNZ3IitSR
key:                  implicit-hie-0.1.2.7-5uI3FDBz7fb6YiNZ3IitSR
license:              BSD-3-Clause
copyright:            2020
maintainer:           avi.the.coder@gmail.com
author:               Avi Dessauer
homepage:             https://github.com/Avi-D-coder/implicit-hie#readme
synopsis:             Auto generate hie-bios cradles & hie.yaml
description:
    Auto generate a stack or cabal multi component hie.yaml file

category:             Development, Tools, Hie, HLS
abi:                  95469c5174db908a1c2f0dd907b51214
exposed:              True
exposed-modules:      Hie.Cabal.Parser Hie.Locate Hie.Yaml
hidden-modules:       Paths_implicit_hie
import-dirs:          /usr/lib/ghc-9.0.2/site-local/implicit-hie-0.1.2.7
library-dirs:         /usr/lib/ghc-9.0.2/site-local/implicit-hie-0.1.2.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-implicit-hie
hs-libraries:         HSimplicit-hie-0.1.2.7-5uI3FDBz7fb6YiNZ3IitSR
depends:
    attoparsec-0.14.4-9IH2L6miCIy2xrqYTi2NtA base-4.15.1.0
    directory-1.3.6.2 filepath-1.4.2.1
    filepattern-0.1.3-A8JLvoJPPtXXjTB7I6ej9 text-1.2.5.0
    transformers-0.5.6.2 yaml-0.11.8.0-x3l9kyc5xFAgP87433dI1

haddock-interfaces:
    /usr/share/doc/haskell-implicit-hie/html/implicit-hie.haddock

haddock-html:         /usr/share/doc/haskell-implicit-hie/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
